@@ -16,11 +16,11 @@ def time_series_dataframe(start_date,end_date,freq='1H',datetime_column_name='ho
     df = date_range_dataframe(start_date,end_date,freq=freq,column_name=datetime_column_name)
     shape = df.shape
     if weekday_dummies:
-        df = pd.concat([df,make_dummies(df.iloc[:,0].dt.weekday)],axis=1)
+        df = pd.concat([df,make_dummies(pd.Series(df.iloc[:,0].dt.weekday, name = 'weekday_dummie'))],axis=1)
     if month_dummies:
-        df = pd.concat([df,make_dummies(df.iloc[:,0].dt.month)],axis=1)
+        df = pd.concat([df,make_dummies(pd.Series(df.iloc[:,0].dt.month, name = 'month_dummie'))],axis=1)
     if hour_dummies:
-        df = pd.concat([df,make_dummies(df.iloc[:,0].dt.hour)],axis=1)
+        df = pd.concat([df,make_dummies(pd.Series(df.iloc[:,0].dt.hour, name = 'hour_dummie'))],axis=1)
     if year_sin_cos:
         df = pd.concat([df,year_sincos_array(shape[0],start_date,end_date)],axis=1)
     if hour_sin_cos:
